# Oauth2Auth

Configuration for OAuth2 authentication.  Systems using this will exchange credentials with the configured token endpoint, providing them with an access token. It will use this access token to perform bearer authentication. The credential exchange will either use a hardcoded password (client_secret) or perform oidc federation (federated_audience).  At least one of client_secret or federated_audience must be set to a non-empty value. If federated_audience is set, it will be used. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token_url** | **str** | The url from which to fetch access tokens.  | 
**client_id** | **str** | The client id to present to the token endpoint  | 
**client_secret** | **str** | The secret to present when doing credential authentication  | [optional] 
**federated_audience** | **str** | The audience to provide when performing OIDC federation.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


